summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/sega16sp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/sega16sp.cpp')
-rw-r--r--src/mame/video/sega16sp.cpp21
1 files changed, 10 insertions, 11 deletions
diff --git a/src/mame/video/sega16sp.cpp b/src/mame/video/sega16sp.cpp
index e5609298baf..970f1a40b90 100644
--- a/src/mame/video/sega16sp.cpp
+++ b/src/mame/video/sega16sp.cpp
@@ -656,21 +656,20 @@ bootleg_sys16a_sprite_device::bootleg_sys16a_sprite_device(const machine_config
//-------------------------------------------------
// static_set_remap -- configure sprite address
// remapping
//-------------------------------------------------
-void bootleg_sys16a_sprite_device::static_set_remap(device_t &device, uint8_t offs0, uint8_t offs1, uint8_t offs2, uint8_t offs3, uint8_t offs4, uint8_t offs5, uint8_t offs6, uint8_t offs7)
+void bootleg_sys16a_sprite_device::set_remap(uint8_t offs0, uint8_t offs1, uint8_t offs2, uint8_t offs3, uint8_t offs4, uint8_t offs5, uint8_t offs6, uint8_t offs7)
{
- bootleg_sys16a_sprite_device &target = downcast<bootleg_sys16a_sprite_device &>(device);
- target.m_addrmap[0] = offs0;
- target.m_addrmap[1] = offs1;
- target.m_addrmap[2] = offs2;
- target.m_addrmap[3] = offs3;
- target.m_addrmap[4] = offs4;
- target.m_addrmap[5] = offs5;
- target.m_addrmap[6] = offs6;
- target.m_addrmap[7] = offs7;
+ m_addrmap[0] = offs0;
+ m_addrmap[1] = offs1;
+ m_addrmap[2] = offs2;
+ m_addrmap[3] = offs3;
+ m_addrmap[4] = offs4;
+ m_addrmap[5] = offs5;
+ m_addrmap[6] = offs6;
+ m_addrmap[7] = offs7;
}
@@ -656,21 +656,20 @@ bootleg_sys16a_sprite_device::bootleg_sys16a_sprite_device(const machine_config
//-------------------------------------------------
-// static_set_remap -- configure sprite address
+// set_remap -- configure sprite address
// remapping
//-------------------------------------------------